Abstract or concrete class with typed constructor parameters and instances.
Instance described by the constructor.
Ordered constructor parameter types.
abstract class Entity { constructor(readonly id: number) {}}const EntityClass: AbstractConstructor<Entity, [id: number]> = Entity; Copy
abstract class Entity { constructor(readonly id: number) {}}const EntityClass: AbstractConstructor<Entity, [id: number]> = Entity;
Abstract or concrete class with typed constructor parameters and instances.