Object with arbitrary numeric or string keys and values.
This alias retains the broad defaults of KeyValue. Specify key and value types with KeyValue when their shapes are known.
KeyValue
const metadata: AnyObject = { id: 1, active: true }; Copy
const metadata: AnyObject = { id: 1, active: true };
Object with arbitrary numeric or string keys and values.