Value distinguished from structurally identical values by a type-only brand.
Underlying value type.
Unique name that identifies the branded value.
A brand adds no runtime property or validation. Create branded values only after validating or otherwise establishing their meaning.
type UserId = Brand<string, 'UserId'>;const userId = 'user-1' as UserId; Copy
type UserId = Brand<string, 'UserId'>;const userId = 'user-1' as UserId;
Value distinguished from structurally identical values by a type-only brand.